slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPNArnoldiGetLagPreconditioner

Indicates how often the preconditioner is rebuilt.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPNArnoldiGetLagPreconditioner(NEP nep,PetscInt *lag)

Not Collective

### Input Parameter

| nep | - nonlinear eigenvalue solver

### Output Parameter

| lag | - the lag parameter

### See Also

NEPNArnoldiSetLagPreconditioner()

### Level

intermediate

### Location

src/nep/impls/narnoldi/narnoldi.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages